@@ -53,7 +53,7 @@ KasumiAddWindow::KasumiAddWindow(KasumiDic *aDictionary,
 
     window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
     gtk_window_set_position (GTK_WINDOW(window), GTK_WIN_POS_MOUSE);
-    gtk_window_set_title(GTK_WINDOW(window), _("Kasumi"));
+    gtk_window_set_title(GTK_WINDOW(window), _("Kasumi (Register words)"));
     g_signal_connect(G_OBJECT(window), "delete_event",
 		     G_CALLBACK(_call_back_add_window_delete_event), this);
 
@@ -104,113 +104,195 @@ KasumiAddWindow::KasumiAddWindow(KasumiDic *aDictionary,
     FrequencySpin = gtk_spin_button_new(GTK_ADJUSTMENT(adjustment),1.0,0);
     gtk_box_pack_start(GTK_BOX(vbox),GTK_WIDGET(FrequencySpin),FALSE,FALSE,0);
 
+    // creating combo box for "Word Type Category"
+    label = gtk_label_new(_("Word Type Category"));
+    alignment = gtk_alignment_new(0,0.5,0,0);
+    gtk_container_add(GTK_CONTAINER(alignment),GTK_WIDGET(label));
+    gtk_box_pack_start(GTK_BOX(vbox),GTK_WIDGET(alignment),FALSE,FALSE,0);
+
+    string defaultCannaTab = conf->getPropertyValue("DefaultAddingWordType");
+
+    GtkListStore *gWordTypeCategoryList = gtk_list_store_new(WORDTYPE_NUM_COLS,G_TYPE_STRING,G_TYPE_POINTER);
+    GtkTreeIter iter;
+    WordTypeList::iterator p = KasumiWordType::beginWordTypeList();
+    list<string> wordCategoryList;
+    while(p != KasumiWordType::endWordTypeList())
+    {
+	string category = (*p)->getCategory();
+	if( find( wordCategoryList.begin(), wordCategoryList.end(), category )
+	    == wordCategoryList.end() )
+	{
+	    wordCategoryList.push_back( category );
+
+	    gtk_list_store_append(gWordTypeCategoryList,&iter);
+	    gtk_list_store_set(gWordTypeCategoryList,&iter,
+			       COL_UI_STRING, category.c_str(),
+			       COL_WORDTYPE_POINTER, (*p),
+			       -1);
+
+	    if((*p)->getCannaTab() == defaultCannaTab)
+		defaultWordTypeCategoryIter = iter;
+	}
+
+	p++;
+    }
+    WordTypeCategoryCombo = gtk_combo_box_new_with_model(GTK_TREE_MODEL(gWordTypeCategoryList));
+    GtkCellRenderer *renderer = GTK_CELL_RENDERER(gtk_cell_renderer_text_new());
+    gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(WordTypeCategoryCombo), renderer, TRUE);
+    gtk_cell_layout_set_attributes(GTK_CELL_LAYOUT(WordTypeCategoryCombo), renderer,
+				   "text", COL_UI_STRING,
+				   NULL);
+    gtk_combo_box_set_active_iter(GTK_COMBO_BOX(WordTypeCategoryCombo), &defaultWordTypeCategoryIter);
+    gtk_box_pack_start(GTK_BOX(vbox),
+		       GTK_WIDGET(WordTypeCategoryCombo),FALSE,FALSE,0);
+    g_signal_connect(G_OBJECT(WordTypeCategoryCombo),"changed",
+		     G_CALLBACK(_call_back_word_type_category_changed),this);
+
+
     // creating combo box for "Word Type"
     label = gtk_label_new(_("Word Type"));
     alignment = gtk_alignment_new(0,0.5,0,0);
     gtk_container_add(GTK_CONTAINER(alignment),GTK_WIDGET(label));
     gtk_box_pack_start(GTK_BOX(vbox),GTK_WIDGET(alignment),FALSE,FALSE,0);
 
-    GtkListStore *gWordTypeList = gtk_list_store_new(WORDTYPE_NUM_COLS,G_TYPE_STRING,G_TYPE_POINTER);
-    GtkTreeIter iter;
-    string defaultCannaTab = conf->getPropertyValue("DefaultAddingWordType");
-    WordTypeList::iterator p = KasumiWordType::beginWordTypeList();
-    while(p != KasumiWordType::endWordTypeList())
-    {
-	gtk_list_store_append(gWordTypeList,&iter);
-	gtk_list_store_set(gWordTypeList,&iter,
-			   COL_UI_STRING, (*p)->getUIString().c_str(),
-			   COL_WORDTYPE_POINTER, (*p),
-			   -1);
-	if((*p)->getCannaTab() == defaultCannaTab)
-	    defaultWordTypeIter = iter;
-	p++;
-    }
+    GtkListStore *gWordTypeList = gtk_list_store_new(WORDTYPE_NUM_COLS,G_TYPE_STRING,G_TYPE_POINTER); // dummy model
     WordTypeCombo = gtk_combo_box_new_with_model(GTK_TREE_MODEL(gWordTypeList));
-    GtkCellRenderer *renderer = GTK_CELL_RENDERER(gtk_cell_renderer_text_new());
+    renderer = GTK_CELL_RENDERER(gtk_cell_renderer_text_new());
     gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(WordTypeCombo), renderer, TRUE);
     gtk_cell_layout_set_attributes(GTK_CELL_LAYOUT(WordTypeCombo), renderer,
 				   "text", COL_UI_STRING,
 				   NULL);
-    gtk_combo_box_set_active_iter(GTK_COMBO_BOX(WordTypeCombo), &defaultWordTypeIter);
     gtk_box_pack_start(GTK_BOX(vbox),
 		       GTK_WIDGET(WordTypeCombo),FALSE,FALSE,0);
+    ChangeWordTypeList(true);
 
     // creating box for buttons
     GtkWidget *hbutton_box = gtk_hbutton_box_new();
     gtk_button_box_set_layout(GTK_BUTTON_BOX(hbutton_box),GTK_BUTTONBOX_SPREAD);
     gtk_box_pack_start(GTK_BOX(vbox),GTK_WIDGET(hbutton_box),FALSE,FALSE,0);
 
-    // creating buttons and configure shortcut key
-    GtkWidget *button = gtk_button_new();
-    label = gtk_label_new(_("Quit"));
-    GtkWidget *button_image = gtk_image_new_from_stock(GTK_STOCK_QUIT,
-						       GTK_ICON_SIZE_BUTTON);
-    GtkWidget *in_box = gtk_hbox_new(FALSE, 0);
-    gtk_box_pack_start(GTK_BOX(in_box), button_image, FALSE, FALSE, 3);
-    gtk_box_pack_start(GTK_BOX(in_box), label, FALSE, FALSE, 3);
-    gtk_container_add(GTK_CONTAINER(button),in_box);
-    gtk_box_pack_start(GTK_BOX(hbutton_box),GTK_WIDGET(button),TRUE,TRUE,0);
-    g_signal_connect(G_OBJECT(button),"clicked",
-		     G_CALLBACK(_call_back_add_window_quit),this);
-    GtkAccelGroup *accel = gtk_accel_group_new();
-    gtk_window_add_accel_group(GTK_WINDOW(window), accel);
-    string key = string("Ctrl+Q");
-    gtk_widget_add_accelerator(button, "clicked", accel,
-			       getAccelKey(key),
-			       getModifierType(key),
-			       GTK_ACCEL_VISIBLE);
-    gtk_tooltips_set_tip(Tooltips, button,
-			 _("Quit this application"),
-			 _("Save dictionary and quit this application."));
+    if( conf->getPropertyValue("StartupMode") == "EXCLUSIVE" )
+    {
+	GtkWidget *button = gtk_button_new();
+	label = gtk_label_new(_("Add"));
+	GtkWidget *button_image = gtk_image_new_from_stock(GTK_STOCK_ADD,
+						GTK_ICON_SIZE_BUTTON);
+	GtkWidget *in_box = gtk_hbox_new(FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(in_box), button_image, FALSE, FALSE, 3);
+	gtk_box_pack_start(GTK_BOX(in_box), label, FALSE, FALSE, 3);
+	gtk_container_add(GTK_CONTAINER(button),in_box);
+	gtk_box_pack_start(GTK_BOX(hbutton_box),GTK_WIDGET(button),TRUE,TRUE,0);
+	g_signal_connect(G_OBJECT(button),"clicked",
+			 G_CALLBACK(_call_back_add_window_add),this);
+	GtkAccelGroup *accel = gtk_accel_group_new();
+	gtk_window_add_accel_group(GTK_WINDOW(window), accel);
+	string key = string("Ctrl+A");
+	gtk_widget_add_accelerator(button, "clicked", accel,
+				   getAccelKey(key),
+				   getModifierType(key),
+				   GTK_ACCEL_VISIBLE);
+	gtk_tooltips_set_tip(Tooltips, button,
+			     _("Add entered word and quit registration."),
+			     _("If all the necessary items are filled in, add entered word and quit registration."));
 
-    button = gtk_button_new();
-    label = gtk_label_new(_("Add"));
-    button_image = gtk_image_new_from_stock(GTK_STOCK_ADD,
-					    GTK_ICON_SIZE_BUTTON);
-    in_box = gtk_hbox_new(FALSE, 0);
-    gtk_box_pack_start(GTK_BOX(in_box), button_image, FALSE, FALSE, 3);
-    gtk_box_pack_start(GTK_BOX(in_box), label, FALSE, FALSE, 3);
-    gtk_container_add(GTK_CONTAINER(button),in_box);
-    gtk_box_pack_start(GTK_BOX(hbutton_box),GTK_WIDGET(button),TRUE,TRUE,0);
-    g_signal_connect(G_OBJECT(button),"clicked",
-		     G_CALLBACK(_call_back_add_window_add),this);
-    accel = gtk_accel_group_new();
-    gtk_window_add_accel_group(GTK_WINDOW(window), accel);
-    key = string("Ctrl+A");
-    gtk_widget_add_accelerator(button, "clicked", accel,
-			       getAccelKey(key),
-			       getModifierType(key),
-			       GTK_ACCEL_VISIBLE);
-    gtk_tooltips_set_tip(Tooltips, button,
-			 _("Add entered word"),
-			 _("If all the necessary items are filled in, add entered word."));
+	button = gtk_button_new();
+	label = gtk_label_new(_("Cancel"));
+	button_image = gtk_image_new_from_stock(GTK_STOCK_QUIT,
+						GTK_ICON_SIZE_BUTTON);
+	in_box = gtk_hbox_new(FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(in_box), button_image, FALSE, FALSE, 3);
+	gtk_box_pack_start(GTK_BOX(in_box), label, FALSE, FALSE, 3);
+	gtk_container_add(GTK_CONTAINER(button),in_box);
+	gtk_box_pack_start(GTK_BOX(hbutton_box),GTK_WIDGET(button),TRUE,TRUE,0);
+	g_signal_connect(G_OBJECT(button),"clicked",
+			 G_CALLBACK(_call_back_add_window_quit),this);
+	accel = gtk_accel_group_new();
+	gtk_window_add_accel_group(GTK_WINDOW(window), accel);
+	key = string("Ctrl+C");
+	gtk_widget_add_accelerator(button, "clicked", accel,
+				   getAccelKey(key),
+				   getModifierType(key),
+				   GTK_ACCEL_VISIBLE);
+	gtk_tooltips_set_tip(Tooltips, button,
+			     _("Cancel registration and quit."),
+			     _("Cancel registration and quit."));
 
-    button = gtk_button_new();
-    label = gtk_label_new(_("Edit"));
-    button_image = gtk_image_new_from_stock(GTK_STOCK_FIND_AND_REPLACE,
-					    GTK_ICON_SIZE_BUTTON);
-    in_box = gtk_hbox_new(FALSE, 0);
-    gtk_box_pack_start(GTK_BOX(in_box), button_image, FALSE, FALSE, 3);
-    gtk_box_pack_start(GTK_BOX(in_box), label, FALSE, FALSE, 3);
-    gtk_container_add(GTK_CONTAINER(button),in_box);
-    gtk_box_pack_start(GTK_BOX(hbutton_box),GTK_WIDGET(button),TRUE,TRUE,0);
-    g_signal_connect(G_OBJECT(button),"clicked",
-		     G_CALLBACK(_call_back_manage_mode),this);
-    accel = gtk_accel_group_new();
-    gtk_window_add_accel_group(GTK_WINDOW(window), accel);
-    key = string("Ctrl+M");
-    gtk_widget_add_accelerator(button, "clicked", accel,
-			       getAccelKey(key),
-			       getModifierType(key),
-			       GTK_ACCEL_VISIBLE);
-    gtk_tooltips_set_tip(Tooltips, button,
-			 _("Manage mode"),
-			 _("Make the shift to manage mode to modify and remove registered words."));
+	gtk_window_set_keep_above(GTK_WINDOW(window), TRUE);
+    }
+    else
+    {
+	// ADD mode
+	// creating buttons and configure shortcut key
+	GtkWidget *button = gtk_button_new();
+	label = gtk_label_new(_("Quit"));
+	GtkWidget *button_image = gtk_image_new_from_stock(GTK_STOCK_QUIT,
+							   GTK_ICON_SIZE_BUTTON);
+	GtkWidget *in_box = gtk_hbox_new(FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(in_box), button_image, FALSE, FALSE, 3);
+	gtk_box_pack_start(GTK_BOX(in_box), label, FALSE, FALSE, 3);
+	gtk_container_add(GTK_CONTAINER(button),in_box);
+	gtk_box_pack_start(GTK_BOX(hbutton_box),GTK_WIDGET(button),TRUE,TRUE,0);
+	g_signal_connect(G_OBJECT(button),"clicked",
+			 G_CALLBACK(_call_back_add_window_quit),this);
+	GtkAccelGroup *accel = gtk_accel_group_new();
+	gtk_window_add_accel_group(GTK_WINDOW(window), accel);
+	string key = string("Ctrl+Q");
+	gtk_widget_add_accelerator(button, "clicked", accel,
+				   getAccelKey(key),
+				   getModifierType(key),
+				   GTK_ACCEL_VISIBLE);
+	gtk_tooltips_set_tip(Tooltips, button,
+			     _("Quit this application"),
+			     _("Save dictionary and quit this application."));
 
+	button = gtk_button_new();
+	label = gtk_label_new(_("Add"));
+	button_image = gtk_image_new_from_stock(GTK_STOCK_ADD,
+						GTK_ICON_SIZE_BUTTON);
+	in_box = gtk_hbox_new(FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(in_box), button_image, FALSE, FALSE, 3);
+	gtk_box_pack_start(GTK_BOX(in_box), label, FALSE, FALSE, 3);
+	gtk_container_add(GTK_CONTAINER(button),in_box);
+	gtk_box_pack_start(GTK_BOX(hbutton_box),GTK_WIDGET(button),TRUE,TRUE,0);
+	g_signal_connect(G_OBJECT(button),"clicked",
+			 G_CALLBACK(_call_back_add_window_add),this);
+	accel = gtk_accel_group_new();
+	gtk_window_add_accel_group(GTK_WINDOW(window), accel);
+	key = string("Ctrl+A");
+	gtk_widget_add_accelerator(button, "clicked", accel,
+				   getAccelKey(key),
+				   getModifierType(key),
+				   GTK_ACCEL_VISIBLE);
+	gtk_tooltips_set_tip(Tooltips, button,
+			     _("Add entered word"),
+			     _("If all the necessary items are filled in, add entered word."));
 
-    // get selection at the time of launching
-    g_signal_connect(G_OBJECT(SpellingEntry),"selection_received",
-		     G_CALLBACK(_call_back_selection_data_received),NULL);
+	button = gtk_button_new();
+	label = gtk_label_new(_("Edit"));
+	button_image = gtk_image_new_from_stock(GTK_STOCK_FIND_AND_REPLACE,
+						GTK_ICON_SIZE_BUTTON);
+	in_box = gtk_hbox_new(FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(in_box), button_image, FALSE, FALSE, 3);
+	gtk_box_pack_start(GTK_BOX(in_box), label, FALSE, FALSE, 3);
+	gtk_container_add(GTK_CONTAINER(button),in_box);
+	gtk_box_pack_start(GTK_BOX(hbutton_box),GTK_WIDGET(button),TRUE,TRUE,0);
+	g_signal_connect(G_OBJECT(button),"clicked",
+			 G_CALLBACK(_call_back_manage_mode),this);
+	accel = gtk_accel_group_new();
+	gtk_window_add_accel_group(GTK_WINDOW(window), accel);
+	key = string("Ctrl+M");
+	gtk_widget_add_accelerator(button, "clicked", accel,
+				   getAccelKey(key),
+				   getModifierType(key),
+				   GTK_ACCEL_VISIBLE);
+	gtk_tooltips_set_tip(Tooltips, button,
+			     _("Manage mode"),
+			     _("Make the shift to manage mode to modify and remove registered words."));
+
+	// get selection at the time of launching
+	g_signal_connect(G_OBJECT(SpellingEntry),"selection_received",
+			 G_CALLBACK(_call_back_selection_data_received),NULL);
+    }
   
     gtk_widget_show_all(window);
 
@@ -256,7 +338,7 @@ void KasumiAddWindow::ClickedAddButton(GtkWidget *widget){
 							GTK_DIALOG_DESTROY_WITH_PARENT,
 							GTK_MESSAGE_ERROR,
 							GTK_BUTTONS_CLOSE,
-							_("Invlid entry for Sound."));
+							_("Invalid entry for Sound."));
 	    gtk_dialog_run (GTK_DIALOG (dialog));
 	    gtk_widget_destroy (dialog);
 	    delete(word);
@@ -269,7 +351,7 @@ void KasumiAddWindow::ClickedAddButton(GtkWidget *widget){
 							GTK_DIALOG_DESTROY_WITH_PARENT,
 							GTK_MESSAGE_ERROR,
 							GTK_BUTTONS_CLOSE,
-							_("Invlid entry for Spelling.")
+							_("Invalid entry for Spelling.")
 		);
 	    gtk_dialog_run (GTK_DIALOG (dialog));
 	    gtk_widget_destroy (dialog);
@@ -292,11 +374,24 @@ void KasumiAddWindow::ClickedAddButton(GtkWidget *widget){
 
 	dictionary->appendWord(word);
 
-	gtk_entry_set_text(GTK_ENTRY(SoundEntry), "");
-	gtk_entry_set_text(GTK_ENTRY(SpellingEntry), "");
-	const int FREQ_DEFAULT = conf->getPropertyValueByInt("DefaultFrequency");
-	gtk_spin_button_set_value(GTK_SPIN_BUTTON(FrequencySpin),FREQ_DEFAULT);
-	gtk_combo_box_set_active_iter(GTK_COMBO_BOX(WordTypeCombo), &defaultWordTypeIter);
+	string mode = conf->getPropertyValue("StartupMode");
+	if( mode == "EXCLUSIVE" )
+	{
+	    cout << word->getSpelling() << ","
+                 << word->getSound() << ","
+                 << word->getFrequency() << ","
+                 << word->getWordType()->getCannaTab() << endl;
+	    quit();
+	}
+	else if( mode == "ADD" )
+	{
+	    gtk_entry_set_text(GTK_ENTRY(SoundEntry), "");
+	    gtk_entry_set_text(GTK_ENTRY(SpellingEntry), "");
+	    const int FREQ_DEFAULT = conf->getPropertyValueByInt("DefaultFrequency");
+	    gtk_spin_button_set_value(GTK_SPIN_BUTTON(FrequencySpin),FREQ_DEFAULT);
+	    gtk_combo_box_set_active_iter(GTK_COMBO_BOX(WordTypeCategoryCombo), &defaultWordTypeCategoryIter);
+	    ChangeWordTypeList(true);
+	}
     }catch(KasumiException e){
 	handleException(e);
     }
@@ -307,6 +402,60 @@ void KasumiAddWindow::SwitchToManageMode(){
     delete this;
 }
 
+void KasumiAddWindow::ChangeWordTypeList(bool toDefault = false){
+    GtkTreeIter iter;
+    GtkTreeIter defaultIter;
+    bool defaultFlag = false;
+    KasumiWordType *tmp;
+    string category;
+    string defaultCannaTab = conf->getPropertyValue("DefaultAddingWordType");
+    
+    gtk_combo_box_get_active_iter(GTK_COMBO_BOX(WordTypeCategoryCombo),
+				  &iter);
+
+    gtk_tree_model_get(gtk_combo_box_get_model( GTK_COMBO_BOX(WordTypeCategoryCombo)),
+		       &iter,
+		       COL_WORDTYPE_POINTER, &tmp,
+		       -1 );
+    category = tmp->getCategory();
+    
+    GtkListStore *gWordTypeList = gtk_list_store_new(WORDTYPE_NUM_COLS,G_TYPE_STRING,G_TYPE_POINTER);
+    WordTypeList::iterator p = KasumiWordType::beginWordTypeList();
+    while(p != KasumiWordType::endWordTypeList())
+    {
+	if( (*p)->getCategory() == category )
+	{
+	    gtk_list_store_append(gWordTypeList,&iter);
+	    if( (*p)->getPos().size() != 0 )
+		gtk_list_store_set(gWordTypeList,&iter,
+				   COL_UI_STRING, (*p)->getPos().c_str(),
+				   COL_WORDTYPE_POINTER, (*p),
+				   -1);
+	    else
+		gtk_list_store_set(gWordTypeList,&iter,
+				   COL_UI_STRING, (*p)->getCategory().c_str(),
+				   COL_WORDTYPE_POINTER, (*p),
+				   -1);
+
+	    if( (*p)->getCannaTab() == defaultCannaTab )
+	    {
+		defaultFlag = true;
+		defaultIter = iter;
+	    }
+	}
+
+	p++;
+    }
+
+    gtk_combo_box_set_model(GTK_COMBO_BOX(WordTypeCombo),
+			    GTK_TREE_MODEL(gWordTypeList));
+    if( defaultFlag && toDefault )
+	gtk_combo_box_set_active_iter(GTK_COMBO_BOX(WordTypeCombo),
+				      &defaultIter);
+    else
+	gtk_combo_box_set_active(GTK_COMBO_BOX(WordTypeCombo), 0);
+}
+
 void _call_back_add_window_delete_event(GtkWidget *widget,
 					GdkEvent *event,
 					gpointer data){
@@ -363,3 +512,10 @@ void get_targets(GtkWidget *data){
     gtk_selection_convert(window, GDK_SELECTION_PRIMARY, targets_atom,
 			  GDK_CURRENT_TIME);
 }
+
+void _call_back_word_type_category_changed(GtkWidget *widget,
+					   gpointer data)
+{
+    KasumiAddWindow *window = (KasumiAddWindow *)data;
+    window->ChangeWordTypeList();
+}
