@@ -407,7 +407,7 @@ void KasumiMainWindow::quit(){
     case GTK_RESPONSE_NO:
       break;
     default:
-      cout << "Error: Unexcepted return value of dialog's run" << endl;
+      cerr << "Error: Unexcepted return value of dialog's run" << endl;
       exit(1);
     }
     gtk_widget_destroy (dialog);
@@ -422,7 +422,7 @@ void KasumiMainWindow::ClickedStoreButton(){
     dictionary->store();
     modificationFlag = false;
   }catch(KasumiException e){
-      cout <<  e.getMessage() << endl;
+      cerr <<  e.getMessage() << endl;
       exit(1);
   }
 }
@@ -585,12 +585,13 @@ void KasumiMainWindow::FindNext(bool fromCurrent){
   GtkTreeModel *model = GTK_TREE_MODEL(SortList);
   GtkTreeIter iter;
   KasumiWord *word;
-  bool fromFirst = false;
   GtkTreeIter StartIter;
   int id;
   string searchString = string(gtk_entry_get_text(GTK_ENTRY(mSearchEntry)));
   string comparedString;
-  GtkWidget *dialog;
+
+  // undo the modified text color
+  gtk_widget_modify_text(mSearchEntry, GTK_STATE_NORMAL, NULL);
 
   SearchBy by = SPELLING;
   if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(mSoundRadio))){
@@ -602,22 +603,20 @@ void KasumiMainWindow::FindNext(bool fromCurrent){
       // If no words, do nothing.
       return;
     }
-    fromFirst = true;
   }
   StartIter = iter;
 
   if(fromCurrent){
-    // Search from the selected world
-    // nothing to do ... discourage against calling gtk_tree_model_iter_next
-  }else if(!fromFirst && !gtk_tree_model_iter_next(model,&iter)){
+    // Search from the selected word
+    // nothing to do
+    // to prevent from calling gtk_tree_model_iter_next )
+  }else if(!gtk_tree_model_iter_next(model,&iter)){
     // Search from next word if a certain word is selected.
     // If the selected is the last word, seek from the first word.
     
-    // If no words, do nothing;    
+    // If no words, do nothing;
     if(!gtk_tree_model_get_iter_first(model, &iter))
       return;
-
-    fromFirst = true;
   }
 
   // liner search!
@@ -638,55 +637,34 @@ void KasumiMainWindow::FindNext(bool fromCurrent){
     }
   }while(gtk_tree_model_iter_next(model, &iter));
 
-  
-  // Unless searched from the first word, seek from the head again.
-  if(!fromFirst){
-    dialog = gtk_message_dialog_new (GTK_WINDOW(mWindow),
-                                     GTK_DIALOG_DESTROY_WITH_PARENT,
-                                     GTK_MESSAGE_QUESTION,
-                                     GTK_BUTTONS_YES_NO,
-                                     _("Cannot find a specific word. Search "
-                                       "from first?"));
-    if(gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_YES){
-      gtk_widget_destroy (dialog);
-    
-      if(!gtk_tree_model_get_iter_first(model, &iter))
-        return;
+  // from first
+  gtk_tree_model_get_iter_first(model, &iter);
 
-      // liner search to selected word!
-      do{
-        gtk_tree_model_get(model, &iter, COL_ID, &id, -1);
-        word = KasumiWord::getWordFromID(id);
+  do{
+      gtk_tree_model_get(model, &iter, COL_ID, &id, -1);
+      word = KasumiWord::getWordFromID(id);
 
-        if(by == SPELLING){
-          comparedString = word->getSpellingByUTF8();
-        }else{
-          comparedString = word->getSoundByUTF8();
-        }
+      if(by == SPELLING){
+	  comparedString = word->getSpellingByUTF8();
+      }else{
+	  comparedString = word->getSoundByUTF8();
+      }
 
-        if(comparedString.find(searchString,0) == 0){
-          gtk_tree_selection_select_iter(SortListSelection,&iter);
-          return;
-        }
-      }while(gtk_tree_model_iter_next(model, &iter) &&
-             (StartIter.user_data != iter.user_data ||
-              StartIter.user_data2 != iter.user_data2 ||
-              StartIter.user_data3 != iter.user_data3));
-    }else{
-      gtk_widget_destroy(dialog);
-      //      gtk_tree_selection_unselect_all(SortListSelection);      
-      return;
-    }
-  }
+      if(comparedString.find(searchString,0) == 0){
+	  gtk_tree_selection_select_iter(SortListSelection, &iter);
+	  return; // succeed searching
+      }
 
-  dialog = gtk_message_dialog_new(GTK_WINDOW(mWindow),
-                                  GTK_DIALOG_DESTROY_WITH_PARENT,
-                                  GTK_MESSAGE_WARNING,
-                                  GTK_BUTTONS_OK,
-                                  _("Cannot find a specific word."));
-  gtk_dialog_run(GTK_DIALOG (dialog));
-  gtk_widget_destroy(dialog);
-  //  gtk_tree_selection_unselect_all(SortListSelection);
+  }while(gtk_tree_model_iter_next(model, &iter) &&
+	 (StartIter.user_data != iter.user_data ||
+	  StartIter.user_data2 != iter.user_data2 ||
+	  StartIter.user_data3 != iter.user_data3));
+
+  // found nothing
+  GdkColor red;
+  red.red = 65535;
+  red.green = red.blue = 0;
+  gtk_widget_modify_text(mSearchEntry, GTK_STATE_NORMAL, &red);
 }
 
 void KasumiMainWindow::SortBy(GtkTreeViewColumn *column){
@@ -739,9 +717,12 @@ void KasumiMainWindow::appendedWord(KasumiWord *word){
   modificationFlag = true;
 
   // set the vertical scroll bar of the tree view undermost
+  // removed: These codes doesn't work well. 
+/*
   GtkAdjustment *adjustment =
     gtk_scrolled_window_get_vadjustment(GTK_SCROLLED_WINDOW(mScrolledWindow));
   gtk_adjustment_set_value(adjustment, adjustment->upper);
+*/
   
   // start editing for spelling forcibly
   GtkTreePath *path = gtk_tree_model_get_path(SortList, &sort_iter);
@@ -969,7 +950,7 @@ guint getAccelKey(const string &key){
   else if(shortkey == "8") return GDK_8;
   else if(shortkey == "9") return GDK_9;
   
-  cout << "Invalid shortcut key option: " << key << endl;
+  cerr << "Invalid shortcut key option: " << key << endl;
   exit(1);
 }
 
@@ -989,7 +970,7 @@ GdkModifierType getModifierType(const string &key){
     return GDK_MOD1_MASK;
   }
 
-  cout << "Invalid mask option: " << key << endl;
+  cerr << "Invalid mask option: " << key << endl;
   exit(1);
 }
 
@@ -1019,10 +1000,11 @@ gint sortFuncBySound(GtkTreeModel *model,
   const char *str_b = word_b->getSoundByUTF8().c_str();
   int size_a = word_a->getSound().size();
   int size_b = word_b->getSound().size();
-  int size = (size_a > size_b) ? size_a : size_b;
+  int size = (size_a < size_b) ? size_a : size_b;
   int i,a,b;
   unsigned char first_a,second_a,third_a;
   unsigned char first_b,second_b,third_b;
+
   
   // compare Hiragana string encoded in UTF8
   for(i=0;i<size;i+=3){
@@ -1034,38 +1016,14 @@ gint sortFuncBySound(GtkTreeModel *model,
     third_b = static_cast<unsigned char> (str_b[i+2]);
 
     // confirm that current characters are Hiragana
-    if(first_a == 0xe3 && first_b == 0xe3){
-      if((second_a == 0x81 && third_a >= 0x81 && third_a <= 0xbf) ||
-         (second_a == 0x82 && third_a >= 0x80 && third_a <= 0x94) ||
-         (second_a == 0x83 && third_a == 0xbc)){
-        a = second_a * 256 + third_a;
-      }else{
-        cout << "invalid character or not hiragana" << endl;
-        cout << str_a << endl;
-        exit(1);
-      }
+    a = first_a * 65535 + second_a * 256 + third_a;
+    b = first_b * 65535 + second_b * 256 + third_b;
 
-      if((second_b == 0x81 && third_b >= 0x81 && third_b <= 0xbf) ||
-         (second_b == 0x82 && third_b >= 0x80 && third_b <= 0x94) ||
-         (second_b == 0x83 && third_b == 0xbc)){
-        b = second_b * 256 + third_b;
-      }else{
-        cout << "invalid character or not hiragana" << endl;
-        cout << str_b << endl;
-        exit(1);
-      }
-
-      if(a != b){
-        return a - b;
-      }
-    }else{
-        cout << "invalid character or not hiragana" << endl;
-        cout << str_a << endl;
-        cout << str_b << endl;
-        exit(1);
+    if(a != b){
+      return a - b;
     }
   }
-  
+
   // one string is the beginning part of another string
   // compare string size
   return size_a - size_b;
