@@ -53,7 +53,7 @@ string KasumiWord::convertUTF8ToEUCJP(const string &aUTF8){
     char *eucjp_buf = (char*)malloc(len_eucjp);
     char *eucjp = eucjp_buf;
 
-    iconv(IconvUTF8_To_EUCJP, &utf8, &len, &eucjp_buf, &len_eucjp);
+    iconv(IconvUTF8_To_EUCJP, const_cast<ICONV_CONST char**>(&utf8), &len, &eucjp_buf, &len_eucjp);
     return string(eucjp);
 }
 
@@ -65,7 +65,7 @@ string KasumiWord::convertEUCJPToUTF8(const string &aEUCJP){
     char *utf8_buf = (char*)malloc(len_utf8);
     char *utf8 = utf8_buf;
 
-    iconv(IconvEUCJP_To_UTF8, &eucjp, &len, &utf8_buf, &len_utf8);
+    iconv(IconvEUCJP_To_UTF8, const_cast<ICONV_CONST char**>(&eucjp), &len, &utf8_buf, &len_utf8);
     return string(utf8);
 }
 
@@ -124,6 +124,10 @@ string KasumiWord::extractInvalidCharacterFromSound(string soundByUTF8){
 		     third >= 0x81 && third <= 0xa0){
 		// symbol marks of two-byte characters
 		continue;
+	    }else if(first == 0xe3 && second == 0x82 &&
+		     third == 0x9b){
+		// dakuon mark
+		continue;
 	    }else{
 		res[0] = str[i];
 		res[1] = str[i+1];
